# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 members: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 type: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] members: List of members in the group. The format depends on the group type:
                 * For address-group: IPv4 addresses or CIDR notation (e.g., ['192.168.1.10', '10.0.0.0/8'])
                 * For port-group: Port numbers or ranges (e.g., ['80', '443', '8000-8080'])
                 * For ipv6-address-group: IPv6 addresses or CIDR notation
        :param pulumi.Input[_builtins.str] type: The type of firewall group. Valid values are:
                 * `address-group` - Group of IPv4 addresses and/or networks (e.g., '192.168.1.10', '10.0.0.0/8')
                 * `port-group` - Group of ports or port ranges (e.g., '80', '443', '8000-8080')
                 * `ipv6-address-group` - Group of IPv6 addresses and/or networks
        :param pulumi.Input[_builtins.str] name: A friendly name for the firewall group to help identify its purpose (e.g., 'Trusted IPs' or 'Web Server Ports'). Must be unique within the site.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the firewall group should be created. If not specified, the default site will be used.
        """
        pulumi.set(__self__, "members", members)
        pulumi.set(__self__, "type", type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def members(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        List of members in the group. The format depends on the group type:
          * For address-group: IPv4 addresses or CIDR notation (e.g., ['192.168.1.10', '10.0.0.0/8'])
          * For port-group: Port numbers or ranges (e.g., ['80', '443', '8000-8080'])
          * For ipv6-address-group: IPv6 addresses or CIDR notation
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "members", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of firewall group. Valid values are:
          * `address-group` - Group of IPv4 addresses and/or networks (e.g., '192.168.1.10', '10.0.0.0/8')
          * `port-group` - Group of ports or port ranges (e.g., '80', '443', '8000-8080')
          * `ipv6-address-group` - Group of IPv6 addresses and/or networks
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the firewall group to help identify its purpose (e.g., 'Trusted IPs' or 'Web Server Ports'). Must be unique within the site.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the firewall group should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] members: List of members in the group. The format depends on the group type:
                 * For address-group: IPv4 addresses or CIDR notation (e.g., ['192.168.1.10', '10.0.0.0/8'])
                 * For port-group: Port numbers or ranges (e.g., ['80', '443', '8000-8080'])
                 * For ipv6-address-group: IPv6 addresses or CIDR notation
        :param pulumi.Input[_builtins.str] name: A friendly name for the firewall group to help identify its purpose (e.g., 'Trusted IPs' or 'Web Server Ports'). Must be unique within the site.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the firewall group should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.str] type: The type of firewall group. Valid values are:
                 * `address-group` - Group of IPv4 addresses and/or networks (e.g., '192.168.1.10', '10.0.0.0/8')
                 * `port-group` - Group of ports or port ranges (e.g., '80', '443', '8000-8080')
                 * `ipv6-address-group` - Group of IPv6 addresses and/or networks
        """
        if members is not None:
            pulumi.set(__self__, "members", members)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of members in the group. The format depends on the group type:
          * For address-group: IPv4 addresses or CIDR notation (e.g., ['192.168.1.10', '10.0.0.0/8'])
          * For port-group: Port numbers or ranges (e.g., ['80', '443', '8000-8080'])
          * For ipv6-address-group: IPv6 addresses or CIDR notation
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "members", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the firewall group to help identify its purpose (e.g., 'Trusted IPs' or 'Web Server Ports'). Must be unique within the site.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the firewall group should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of firewall group. Valid values are:
          * `address-group` - Group of IPv4 addresses and/or networks (e.g., '192.168.1.10', '10.0.0.0/8')
          * `port-group` - Group of ports or port ranges (e.g., '80', '443', '8000-8080')
          * `ipv6-address-group` - Group of IPv6 addresses and/or networks
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("unifi:firewall/group:Group")
class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `firewall.Group` resource manages reusable groups of addresses or ports that can be referenced in firewall rules (`firewall.Rule`).

        Firewall groups help organize and simplify firewall rule management by allowing you to:
          * Create collections of IP addresses or networks
          * Define sets of ports for specific services
          * Group IPv6 addresses for IPv6-specific rules

        Common use cases include:
          * Creating groups of trusted IP addresses
          * Defining port groups for specific applications
          * Managing access control lists
          * Simplifying rule maintenance by using groups instead of individual IPs/ports

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        config = pulumi.Config()
        laptop_ips = config.require_object("laptopIps")
        can_print = unifi.firewall.Group("can_print",
            name="can-print",
            type="address-group",
            members=laptop_ips)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] members: List of members in the group. The format depends on the group type:
                 * For address-group: IPv4 addresses or CIDR notation (e.g., ['192.168.1.10', '10.0.0.0/8'])
                 * For port-group: Port numbers or ranges (e.g., ['80', '443', '8000-8080'])
                 * For ipv6-address-group: IPv6 addresses or CIDR notation
        :param pulumi.Input[_builtins.str] name: A friendly name for the firewall group to help identify its purpose (e.g., 'Trusted IPs' or 'Web Server Ports'). Must be unique within the site.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the firewall group should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.str] type: The type of firewall group. Valid values are:
                 * `address-group` - Group of IPv4 addresses and/or networks (e.g., '192.168.1.10', '10.0.0.0/8')
                 * `port-group` - Group of ports or port ranges (e.g., '80', '443', '8000-8080')
                 * `ipv6-address-group` - Group of IPv6 addresses and/or networks
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `firewall.Group` resource manages reusable groups of addresses or ports that can be referenced in firewall rules (`firewall.Rule`).

        Firewall groups help organize and simplify firewall rule management by allowing you to:
          * Create collections of IP addresses or networks
          * Define sets of ports for specific services
          * Group IPv6 addresses for IPv6-specific rules

        Common use cases include:
          * Creating groups of trusted IP addresses
          * Defining port groups for specific applications
          * Managing access control lists
          * Simplifying rule maintenance by using groups instead of individual IPs/ports

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        config = pulumi.Config()
        laptop_ips = config.require_object("laptopIps")
        can_print = unifi.firewall.Group("can_print",
            name="can-print",
            type="address-group",
            members=laptop_ips)
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            if members is None and not opts.urn:
                raise TypeError("Missing required property 'members'")
            __props__.__dict__["members"] = members
            __props__.__dict__["name"] = name
            __props__.__dict__["site"] = site
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(Group, __self__).__init__(
            'unifi:firewall/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            members: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] members: List of members in the group. The format depends on the group type:
                 * For address-group: IPv4 addresses or CIDR notation (e.g., ['192.168.1.10', '10.0.0.0/8'])
                 * For port-group: Port numbers or ranges (e.g., ['80', '443', '8000-8080'])
                 * For ipv6-address-group: IPv6 addresses or CIDR notation
        :param pulumi.Input[_builtins.str] name: A friendly name for the firewall group to help identify its purpose (e.g., 'Trusted IPs' or 'Web Server Ports'). Must be unique within the site.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the firewall group should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.str] type: The type of firewall group. Valid values are:
                 * `address-group` - Group of IPv4 addresses and/or networks (e.g., '192.168.1.10', '10.0.0.0/8')
                 * `port-group` - Group of ports or port ranges (e.g., '80', '443', '8000-8080')
                 * `ipv6-address-group` - Group of IPv6 addresses and/or networks
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["members"] = members
        __props__.__dict__["name"] = name
        __props__.__dict__["site"] = site
        __props__.__dict__["type"] = type
        return Group(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def members(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of members in the group. The format depends on the group type:
          * For address-group: IPv4 addresses or CIDR notation (e.g., ['192.168.1.10', '10.0.0.0/8'])
          * For port-group: Port numbers or ranges (e.g., ['80', '443', '8000-8080'])
          * For ipv6-address-group: IPv6 addresses or CIDR notation
        """
        return pulumi.get(self, "members")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A friendly name for the firewall group to help identify its purpose (e.g., 'Trusted IPs' or 'Web Server Ports'). Must be unique within the site.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where the firewall group should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of firewall group. Valid values are:
          * `address-group` - Group of IPv4 addresses and/or networks (e.g., '192.168.1.10', '10.0.0.0/8')
          * `port-group` - Group of ports or port ranges (e.g., '80', '443', '8000-8080')
          * `ipv6-address-group` - Group of IPv6 addresses and/or networks
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ZonePolicyDestination',
    'ZonePolicySchedule',
    'ZonePolicySource',
]

@pulumi.output_type
class ZonePolicyDestination(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "zoneId":
            suggest = "zone_id"
        elif key == "appCategoryIds":
            suggest = "app_category_ids"
        elif key == "appIds":
            suggest = "app_ids"
        elif key == "ipGroupId":
            suggest = "ip_group_id"
        elif key == "matchOppositeIps":
            suggest = "match_opposite_ips"
        elif key == "matchOppositePorts":
            suggest = "match_opposite_ports"
        elif key == "portGroupId":
            suggest = "port_group_id"
        elif key == "webDomains":
            suggest = "web_domains"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ZonePolicyDestination. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ZonePolicyDestination.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ZonePolicyDestination.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 zone_id: _builtins.str,
                 app_category_ids: Optional[Sequence[_builtins.str]] = None,
                 app_ids: Optional[Sequence[_builtins.str]] = None,
                 ip_group_id: Optional[_builtins.str] = None,
                 ips: Optional[Sequence[_builtins.str]] = None,
                 match_opposite_ips: Optional[_builtins.bool] = None,
                 match_opposite_ports: Optional[_builtins.bool] = None,
                 port: Optional[_builtins.int] = None,
                 port_group_id: Optional[_builtins.str] = None,
                 regions: Optional[Sequence[_builtins.str]] = None,
                 web_domains: Optional[Sequence[_builtins.str]] = None):
        """
        :param _builtins.str zone_id: ID of the firewall zone.
        :param Sequence[_builtins.str] app_category_ids: List of application category IDs.
        :param Sequence[_builtins.str] app_ids: List of application IDs.
        :param _builtins.str ip_group_id: ID of the source IP group.
        :param Sequence[_builtins.str] ips: List of source IPs.
        :param _builtins.bool match_opposite_ips: Whether to match opposite IPs.
        :param _builtins.bool match_opposite_ports: Whether to match opposite ports.
        :param _builtins.int port: Source port.
        :param _builtins.str port_group_id: ID of the source port group.
        :param Sequence[_builtins.str] regions: List of regions.
        :param Sequence[_builtins.str] web_domains: List of web domains.
        """
        pulumi.set(__self__, "zone_id", zone_id)
        if app_category_ids is not None:
            pulumi.set(__self__, "app_category_ids", app_category_ids)
        if app_ids is not None:
            pulumi.set(__self__, "app_ids", app_ids)
        if ip_group_id is not None:
            pulumi.set(__self__, "ip_group_id", ip_group_id)
        if ips is not None:
            pulumi.set(__self__, "ips", ips)
        if match_opposite_ips is not None:
            pulumi.set(__self__, "match_opposite_ips", match_opposite_ips)
        if match_opposite_ports is not None:
            pulumi.set(__self__, "match_opposite_ports", match_opposite_ports)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if port_group_id is not None:
            pulumi.set(__self__, "port_group_id", port_group_id)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if web_domains is not None:
            pulumi.set(__self__, "web_domains", web_domains)

    @_builtins.property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> _builtins.str:
        """
        ID of the firewall zone.
        """
        return pulumi.get(self, "zone_id")

    @_builtins.property
    @pulumi.getter(name="appCategoryIds")
    def app_category_ids(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of application category IDs.
        """
        return pulumi.get(self, "app_category_ids")

    @_builtins.property
    @pulumi.getter(name="appIds")
    def app_ids(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of application IDs.
        """
        return pulumi.get(self, "app_ids")

    @_builtins.property
    @pulumi.getter(name="ipGroupId")
    def ip_group_id(self) -> Optional[_builtins.str]:
        """
        ID of the source IP group.
        """
        return pulumi.get(self, "ip_group_id")

    @_builtins.property
    @pulumi.getter
    def ips(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of source IPs.
        """
        return pulumi.get(self, "ips")

    @_builtins.property
    @pulumi.getter(name="matchOppositeIps")
    def match_opposite_ips(self) -> Optional[_builtins.bool]:
        """
        Whether to match opposite IPs.
        """
        return pulumi.get(self, "match_opposite_ips")

    @_builtins.property
    @pulumi.getter(name="matchOppositePorts")
    def match_opposite_ports(self) -> Optional[_builtins.bool]:
        """
        Whether to match opposite ports.
        """
        return pulumi.get(self, "match_opposite_ports")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        Source port.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="portGroupId")
    def port_group_id(self) -> Optional[_builtins.str]:
        """
        ID of the source port group.
        """
        return pulumi.get(self, "port_group_id")

    @_builtins.property
    @pulumi.getter
    def regions(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of regions.
        """
        return pulumi.get(self, "regions")

    @_builtins.property
    @pulumi.getter(name="webDomains")
    def web_domains(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of web domains.
        """
        return pulumi.get(self, "web_domains")


@pulumi.output_type
class ZonePolicySchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dateEnd":
            suggest = "date_end"
        elif key == "dateStart":
            suggest = "date_start"
        elif key == "repeatOnDays":
            suggest = "repeat_on_days"
        elif key == "timeAllDay":
            suggest = "time_all_day"
        elif key == "timeFrom":
            suggest = "time_from"
        elif key == "timeTo":
            suggest = "time_to"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ZonePolicySchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ZonePolicySchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ZonePolicySchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 date: Optional[_builtins.str] = None,
                 date_end: Optional[_builtins.str] = None,
                 date_start: Optional[_builtins.str] = None,
                 mode: Optional[_builtins.str] = None,
                 repeat_on_days: Optional[Sequence[_builtins.str]] = None,
                 time_all_day: Optional[_builtins.bool] = None,
                 time_from: Optional[_builtins.str] = None,
                 time_to: Optional[_builtins.str] = None):
        """
        :param _builtins.str date: Date for the schedule.
        :param _builtins.str date_end: End date for the schedule.
        :param _builtins.str date_start: Start date for the schedule.
        :param _builtins.str mode: Schedule mode. Valid values are `ALWAYS`, `EVERY_DAY`, `EVERY_WEEK`, `ONE_TIME_ONLY`, or `CUSTOM`.
        :param Sequence[_builtins.str] repeat_on_days: Days of the week when schedule repeats. Valid values include `mon`, `tue`, `wed`, `thu`, `fri`, `sat`, and `sun`.
        :param _builtins.bool time_all_day: Whether the schedule applies all day.
        :param _builtins.str time_from: Schedule starting time in 24-hour format (HH:MM).
        :param _builtins.str time_to: Schedule ending time in 24-hour format (HH:MM).
        """
        if date is not None:
            pulumi.set(__self__, "date", date)
        if date_end is not None:
            pulumi.set(__self__, "date_end", date_end)
        if date_start is not None:
            pulumi.set(__self__, "date_start", date_start)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if repeat_on_days is not None:
            pulumi.set(__self__, "repeat_on_days", repeat_on_days)
        if time_all_day is not None:
            pulumi.set(__self__, "time_all_day", time_all_day)
        if time_from is not None:
            pulumi.set(__self__, "time_from", time_from)
        if time_to is not None:
            pulumi.set(__self__, "time_to", time_to)

    @_builtins.property
    @pulumi.getter
    def date(self) -> Optional[_builtins.str]:
        """
        Date for the schedule.
        """
        return pulumi.get(self, "date")

    @_builtins.property
    @pulumi.getter(name="dateEnd")
    def date_end(self) -> Optional[_builtins.str]:
        """
        End date for the schedule.
        """
        return pulumi.get(self, "date_end")

    @_builtins.property
    @pulumi.getter(name="dateStart")
    def date_start(self) -> Optional[_builtins.str]:
        """
        Start date for the schedule.
        """
        return pulumi.get(self, "date_start")

    @_builtins.property
    @pulumi.getter
    def mode(self) -> Optional[_builtins.str]:
        """
        Schedule mode. Valid values are `ALWAYS`, `EVERY_DAY`, `EVERY_WEEK`, `ONE_TIME_ONLY`, or `CUSTOM`.
        """
        return pulumi.get(self, "mode")

    @_builtins.property
    @pulumi.getter(name="repeatOnDays")
    def repeat_on_days(self) -> Optional[Sequence[_builtins.str]]:
        """
        Days of the week when schedule repeats. Valid values include `mon`, `tue`, `wed`, `thu`, `fri`, `sat`, and `sun`.
        """
        return pulumi.get(self, "repeat_on_days")

    @_builtins.property
    @pulumi.getter(name="timeAllDay")
    def time_all_day(self) -> Optional[_builtins.bool]:
        """
        Whether the schedule applies all day.
        """
        return pulumi.get(self, "time_all_day")

    @_builtins.property
    @pulumi.getter(name="timeFrom")
    def time_from(self) -> Optional[_builtins.str]:
        """
        Schedule starting time in 24-hour format (HH:MM).
        """
        return pulumi.get(self, "time_from")

    @_builtins.property
    @pulumi.getter(name="timeTo")
    def time_to(self) -> Optional[_builtins.str]:
        """
        Schedule ending time in 24-hour format (HH:MM).
        """
        return pulumi.get(self, "time_to")


@pulumi.output_type
class ZonePolicySource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "zoneId":
            suggest = "zone_id"
        elif key == "clientMacs":
            suggest = "client_macs"
        elif key == "ipGroupId":
            suggest = "ip_group_id"
        elif key == "matchOppositeIps":
            suggest = "match_opposite_ips"
        elif key == "matchOppositeNetworks":
            suggest = "match_opposite_networks"
        elif key == "matchOppositePorts":
            suggest = "match_opposite_ports"
        elif key == "networkIds":
            suggest = "network_ids"
        elif key == "portGroupId":
            suggest = "port_group_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ZonePolicySource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ZonePolicySource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ZonePolicySource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 zone_id: _builtins.str,
                 client_macs: Optional[Sequence[_builtins.str]] = None,
                 ip_group_id: Optional[_builtins.str] = None,
                 ips: Optional[Sequence[_builtins.str]] = None,
                 mac: Optional[_builtins.str] = None,
                 macs: Optional[Sequence[_builtins.str]] = None,
                 match_opposite_ips: Optional[_builtins.bool] = None,
                 match_opposite_networks: Optional[_builtins.bool] = None,
                 match_opposite_ports: Optional[_builtins.bool] = None,
                 network_ids: Optional[Sequence[_builtins.str]] = None,
                 port: Optional[_builtins.int] = None,
                 port_group_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str zone_id: ID of the firewall zone.
        :param Sequence[_builtins.str] client_macs: List of client MAC addresses.
        :param _builtins.str ip_group_id: ID of the source IP group.
        :param Sequence[_builtins.str] ips: List of source IPs.
        :param _builtins.str mac: Source MAC address.
        :param Sequence[_builtins.str] macs: List of MAC addresses.
        :param _builtins.bool match_opposite_ips: Whether to match opposite IPs.
        :param _builtins.bool match_opposite_networks: Whether to match opposite networks.
        :param _builtins.bool match_opposite_ports: Whether to match opposite ports.
        :param Sequence[_builtins.str] network_ids: List of network IDs.
        :param _builtins.int port: Source port.
        :param _builtins.str port_group_id: ID of the source port group.
        """
        pulumi.set(__self__, "zone_id", zone_id)
        if client_macs is not None:
            pulumi.set(__self__, "client_macs", client_macs)
        if ip_group_id is not None:
            pulumi.set(__self__, "ip_group_id", ip_group_id)
        if ips is not None:
            pulumi.set(__self__, "ips", ips)
        if mac is not None:
            pulumi.set(__self__, "mac", mac)
        if macs is not None:
            pulumi.set(__self__, "macs", macs)
        if match_opposite_ips is not None:
            pulumi.set(__self__, "match_opposite_ips", match_opposite_ips)
        if match_opposite_networks is not None:
            pulumi.set(__self__, "match_opposite_networks", match_opposite_networks)
        if match_opposite_ports is not None:
            pulumi.set(__self__, "match_opposite_ports", match_opposite_ports)
        if network_ids is not None:
            pulumi.set(__self__, "network_ids", network_ids)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if port_group_id is not None:
            pulumi.set(__self__, "port_group_id", port_group_id)

    @_builtins.property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> _builtins.str:
        """
        ID of the firewall zone.
        """
        return pulumi.get(self, "zone_id")

    @_builtins.property
    @pulumi.getter(name="clientMacs")
    def client_macs(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of client MAC addresses.
        """
        return pulumi.get(self, "client_macs")

    @_builtins.property
    @pulumi.getter(name="ipGroupId")
    def ip_group_id(self) -> Optional[_builtins.str]:
        """
        ID of the source IP group.
        """
        return pulumi.get(self, "ip_group_id")

    @_builtins.property
    @pulumi.getter
    def ips(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of source IPs.
        """
        return pulumi.get(self, "ips")

    @_builtins.property
    @pulumi.getter
    def mac(self) -> Optional[_builtins.str]:
        """
        Source MAC address.
        """
        return pulumi.get(self, "mac")

    @_builtins.property
    @pulumi.getter
    def macs(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of MAC addresses.
        """
        return pulumi.get(self, "macs")

    @_builtins.property
    @pulumi.getter(name="matchOppositeIps")
    def match_opposite_ips(self) -> Optional[_builtins.bool]:
        """
        Whether to match opposite IPs.
        """
        return pulumi.get(self, "match_opposite_ips")

    @_builtins.property
    @pulumi.getter(name="matchOppositeNetworks")
    def match_opposite_networks(self) -> Optional[_builtins.bool]:
        """
        Whether to match opposite networks.
        """
        return pulumi.get(self, "match_opposite_networks")

    @_builtins.property
    @pulumi.getter(name="matchOppositePorts")
    def match_opposite_ports(self) -> Optional[_builtins.bool]:
        """
        Whether to match opposite ports.
        """
        return pulumi.get(self, "match_opposite_ports")

    @_builtins.property
    @pulumi.getter(name="networkIds")
    def network_ids(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of network IDs.
        """
        return pulumi.get(self, "network_ids")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        Source port.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="portGroupId")
    def port_group_id(self) -> Optional[_builtins.str]:
        """
        ID of the source port group.
        """
        return pulumi.get(self, "port_group_id")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeviceArgs', 'Device']

@pulumi.input_type
class DeviceArgs:
    def __init__(__self__, *,
                 allow_adoption: Optional[pulumi.Input[_builtins.bool]] = None,
                 forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 mac: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Device resource.
        :param pulumi.Input[_builtins.bool] allow_adoption: Whether to automatically adopt the device when creating this resource. When true:
               * The controller will attempt to adopt the device
               * Device must be in a pending adoption state
               * Device must be accessible on the network
               Set to false if you want to manage adoption manually.
        :param pulumi.Input[_builtins.bool] forget_on_destroy: Whether to forget (un-adopt) the device when this resource is destroyed. When true:
               * The device will be removed from the controller
               * The device will need to be readopted to be managed again
               * Device configuration will be reset
               Set to false to keep the device adopted when removing from Terraform management.
        :param pulumi.Input[_builtins.str] mac: The MAC address of the device in standard format (e.g., 'aa:bb:cc:dd:ee:ff'). This is used to identify and manage specific devices that have already been adopted by the controller.
        :param pulumi.Input[_builtins.str] name: A friendly name for the device that will be displayed in the UniFi controller UI. Examples:
               * 'Office-AP-1' for an access point
               * 'Core-Switch-01' for a switch
               * 'Main-Gateway' for a gateway
               Choose descriptive names that indicate location and purpose.
        :param pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]] port_overrides: A list of port-specific configuration overrides for UniFi switches. This allows you to customize individual port settings such as:
                 * Port names and labels for easy identification
                 * Port profiles for VLAN and security settings
                 * Operating modes for special functions
               
               Common use cases include:
                 * Setting up trunk ports for inter-switch connections
                 * Configuring PoE settings for powered devices
                 * Creating mirrored ports for network monitoring
                 * Setting up link aggregation between switches or servers
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the device is located. If not specified, the default site will be used.
        """
        if allow_adoption is not None:
            pulumi.set(__self__, "allow_adoption", allow_adoption)
        if forget_on_destroy is not None:
            pulumi.set(__self__, "forget_on_destroy", forget_on_destroy)
        if mac is not None:
            pulumi.set(__self__, "mac", mac)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_overrides is not None:
            pulumi.set(__self__, "port_overrides", port_overrides)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter(name="allowAdoption")
    def allow_adoption(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to automatically adopt the device when creating this resource. When true:
        * The controller will attempt to adopt the device
        * Device must be in a pending adoption state
        * Device must be accessible on the network
        Set to false if you want to manage adoption manually.
        """
        return pulumi.get(self, "allow_adoption")

    @allow_adoption.setter
    def allow_adoption(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_adoption", value)

    @_builtins.property
    @pulumi.getter(name="forgetOnDestroy")
    def forget_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to forget (un-adopt) the device when this resource is destroyed. When true:
        * The device will be removed from the controller
        * The device will need to be readopted to be managed again
        * Device configuration will be reset
        Set to false to keep the device adopted when removing from Terraform management.
        """
        return pulumi.get(self, "forget_on_destroy")

    @forget_on_destroy.setter
    def forget_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "forget_on_destroy", value)

    @_builtins.property
    @pulumi.getter
    def mac(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The MAC address of the device in standard format (e.g., 'aa:bb:cc:dd:ee:ff'). This is used to identify and manage specific devices that have already been adopted by the controller.
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mac", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the device that will be displayed in the UniFi controller UI. Examples:
        * 'Office-AP-1' for an access point
        * 'Core-Switch-01' for a switch
        * 'Main-Gateway' for a gateway
        Choose descriptive names that indicate location and purpose.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="portOverrides")
    def port_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]]:
        """
        A list of port-specific configuration overrides for UniFi switches. This allows you to customize individual port settings such as:
          * Port names and labels for easy identification
          * Port profiles for VLAN and security settings
          * Operating modes for special functions

        Common use cases include:
          * Setting up trunk ports for inter-switch connections
          * Configuring PoE settings for powered devices
          * Creating mirrored ports for network monitoring
          * Setting up link aggregation between switches or servers
        """
        return pulumi.get(self, "port_overrides")

    @port_overrides.setter
    def port_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]]):
        pulumi.set(self, "port_overrides", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the device is located. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _DeviceState:
    def __init__(__self__, *,
                 allow_adoption: Optional[pulumi.Input[_builtins.bool]] = None,
                 disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 mac: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Device resources.
        :param pulumi.Input[_builtins.bool] allow_adoption: Whether to automatically adopt the device when creating this resource. When true:
               * The controller will attempt to adopt the device
               * Device must be in a pending adoption state
               * Device must be accessible on the network
               Set to false if you want to manage adoption manually.
        :param pulumi.Input[_builtins.bool] disabled: Whether the device is administratively disabled. When true, the device will not forward traffic or provide services.
        :param pulumi.Input[_builtins.bool] forget_on_destroy: Whether to forget (un-adopt) the device when this resource is destroyed. When true:
               * The device will be removed from the controller
               * The device will need to be readopted to be managed again
               * Device configuration will be reset
               Set to false to keep the device adopted when removing from Terraform management.
        :param pulumi.Input[_builtins.str] mac: The MAC address of the device in standard format (e.g., 'aa:bb:cc:dd:ee:ff'). This is used to identify and manage specific devices that have already been adopted by the controller.
        :param pulumi.Input[_builtins.str] name: A friendly name for the device that will be displayed in the UniFi controller UI. Examples:
               * 'Office-AP-1' for an access point
               * 'Core-Switch-01' for a switch
               * 'Main-Gateway' for a gateway
               Choose descriptive names that indicate location and purpose.
        :param pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]] port_overrides: A list of port-specific configuration overrides for UniFi switches. This allows you to customize individual port settings such as:
                 * Port names and labels for easy identification
                 * Port profiles for VLAN and security settings
                 * Operating modes for special functions
               
               Common use cases include:
                 * Setting up trunk ports for inter-switch connections
                 * Configuring PoE settings for powered devices
                 * Creating mirrored ports for network monitoring
                 * Setting up link aggregation between switches or servers
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the device is located. If not specified, the default site will be used.
        """
        if allow_adoption is not None:
            pulumi.set(__self__, "allow_adoption", allow_adoption)
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if forget_on_destroy is not None:
            pulumi.set(__self__, "forget_on_destroy", forget_on_destroy)
        if mac is not None:
            pulumi.set(__self__, "mac", mac)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_overrides is not None:
            pulumi.set(__self__, "port_overrides", port_overrides)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter(name="allowAdoption")
    def allow_adoption(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to automatically adopt the device when creating this resource. When true:
        * The controller will attempt to adopt the device
        * Device must be in a pending adoption state
        * Device must be accessible on the network
        Set to false if you want to manage adoption manually.
        """
        return pulumi.get(self, "allow_adoption")

    @allow_adoption.setter
    def allow_adoption(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_adoption", value)

    @_builtins.property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the device is administratively disabled. When true, the device will not forward traffic or provide services.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disabled", value)

    @_builtins.property
    @pulumi.getter(name="forgetOnDestroy")
    def forget_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to forget (un-adopt) the device when this resource is destroyed. When true:
        * The device will be removed from the controller
        * The device will need to be readopted to be managed again
        * Device configuration will be reset
        Set to false to keep the device adopted when removing from Terraform management.
        """
        return pulumi.get(self, "forget_on_destroy")

    @forget_on_destroy.setter
    def forget_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "forget_on_destroy", value)

    @_builtins.property
    @pulumi.getter
    def mac(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The MAC address of the device in standard format (e.g., 'aa:bb:cc:dd:ee:ff'). This is used to identify and manage specific devices that have already been adopted by the controller.
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mac", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the device that will be displayed in the UniFi controller UI. Examples:
        * 'Office-AP-1' for an access point
        * 'Core-Switch-01' for a switch
        * 'Main-Gateway' for a gateway
        Choose descriptive names that indicate location and purpose.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="portOverrides")
    def port_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]]:
        """
        A list of port-specific configuration overrides for UniFi switches. This allows you to customize individual port settings such as:
          * Port names and labels for easy identification
          * Port profiles for VLAN and security settings
          * Operating modes for special functions

        Common use cases include:
          * Setting up trunk ports for inter-switch connections
          * Configuring PoE settings for powered devices
          * Creating mirrored ports for network monitoring
          * Setting up link aggregation between switches or servers
        """
        return pulumi.get(self, "port_overrides")

    @port_overrides.setter
    def port_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DevicePortOverrideArgs']]]]):
        pulumi.set(self, "port_overrides", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the device is located. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.type_token("unifi:index/device:Device")
class Device(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_adoption: Optional[pulumi.Input[_builtins.bool]] = None,
                 forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 mac: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DevicePortOverrideArgs', 'DevicePortOverrideArgsDict']]]]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `Device` resource manages UniFi network devices such as access points, switches, gateways, etc.

        Devices must first be adopted by the UniFi controller before they can be managed through Terraform. This resource cannot create new devices, but instead allows you to manage existing devices that have already been adopted. The recommended approach is to adopt devices through the UniFi controller UI first, then import them into Terraform using the device's MAC address.

        This resource supports managing device names, port configurations, and other device-specific settings.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_unifi as unifi
        import pulumiverse_unifi as unifi

        disabled = unifi.port.get_profile(name="Disabled")
        poe = unifi.port.Profile("poe",
            name="poe",
            forward="customize",
            native_networkconf_id=native_network_id,
            tagged_networkconf_ids=[some_vlan_network_id],
            poe_mode="auto")
        us24_poe = unifi.Device("us_24_poe",
            mac="01:23:45:67:89:AB",
            name="Switch with POE",
            port_overrides=[
                {
                    "number": 1,
                    "name": "port w/ poe",
                    "port_profile_id": poe.id,
                },
                {
                    "number": 2,
                    "name": "disabled",
                    "port_profile_id": disabled.id,
                },
                {
                    "number": 11,
                    "op_mode": "aggregate",
                    "aggregate_num_ports": 2,
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_adoption: Whether to automatically adopt the device when creating this resource. When true:
               * The controller will attempt to adopt the device
               * Device must be in a pending adoption state
               * Device must be accessible on the network
               Set to false if you want to manage adoption manually.
        :param pulumi.Input[_builtins.bool] forget_on_destroy: Whether to forget (un-adopt) the device when this resource is destroyed. When true:
               * The device will be removed from the controller
               * The device will need to be readopted to be managed again
               * Device configuration will be reset
               Set to false to keep the device adopted when removing from Terraform management.
        :param pulumi.Input[_builtins.str] mac: The MAC address of the device in standard format (e.g., 'aa:bb:cc:dd:ee:ff'). This is used to identify and manage specific devices that have already been adopted by the controller.
        :param pulumi.Input[_builtins.str] name: A friendly name for the device that will be displayed in the UniFi controller UI. Examples:
               * 'Office-AP-1' for an access point
               * 'Core-Switch-01' for a switch
               * 'Main-Gateway' for a gateway
               Choose descriptive names that indicate location and purpose.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DevicePortOverrideArgs', 'DevicePortOverrideArgsDict']]]] port_overrides: A list of port-specific configuration overrides for UniFi switches. This allows you to customize individual port settings such as:
                 * Port names and labels for easy identification
                 * Port profiles for VLAN and security settings
                 * Operating modes for special functions
               
               Common use cases include:
                 * Setting up trunk ports for inter-switch connections
                 * Configuring PoE settings for powered devices
                 * Creating mirrored ports for network monitoring
                 * Setting up link aggregation between switches or servers
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the device is located. If not specified, the default site will be used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DeviceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `Device` resource manages UniFi network devices such as access points, switches, gateways, etc.

        Devices must first be adopted by the UniFi controller before they can be managed through Terraform. This resource cannot create new devices, but instead allows you to manage existing devices that have already been adopted. The recommended approach is to adopt devices through the UniFi controller UI first, then import them into Terraform using the device's MAC address.

        This resource supports managing device names, port configurations, and other device-specific settings.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_unifi as unifi
        import pulumiverse_unifi as unifi

        disabled = unifi.port.get_profile(name="Disabled")
        poe = unifi.port.Profile("poe",
            name="poe",
            forward="customize",
            native_networkconf_id=native_network_id,
            tagged_networkconf_ids=[some_vlan_network_id],
            poe_mode="auto")
        us24_poe = unifi.Device("us_24_poe",
            mac="01:23:45:67:89:AB",
            name="Switch with POE",
            port_overrides=[
                {
                    "number": 1,
                    "name": "port w/ poe",
                    "port_profile_id": poe.id,
                },
                {
                    "number": 2,
                    "name": "disabled",
                    "port_profile_id": disabled.id,
                },
                {
                    "number": 11,
                    "op_mode": "aggregate",
                    "aggregate_num_ports": 2,
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param DeviceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeviceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_adoption: Optional[pulumi.Input[_builtins.bool]] = None,
                 forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 mac: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DevicePortOverrideArgs', 'DevicePortOverrideArgsDict']]]]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeviceArgs.__new__(DeviceArgs)

            __props__.__dict__["allow_adoption"] = allow_adoption
            __props__.__dict__["forget_on_destroy"] = forget_on_destroy
            __props__.__dict__["mac"] = mac
            __props__.__dict__["name"] = name
            __props__.__dict__["port_overrides"] = port_overrides
            __props__.__dict__["site"] = site
            __props__.__dict__["disabled"] = None
        super(Device, __self__).__init__(
            'unifi:index/device:Device',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_adoption: Optional[pulumi.Input[_builtins.bool]] = None,
            disabled: Optional[pulumi.Input[_builtins.bool]] = None,
            forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            mac: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            port_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DevicePortOverrideArgs', 'DevicePortOverrideArgsDict']]]]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None) -> 'Device':
        """
        Get an existing Device resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_adoption: Whether to automatically adopt the device when creating this resource. When true:
               * The controller will attempt to adopt the device
               * Device must be in a pending adoption state
               * Device must be accessible on the network
               Set to false if you want to manage adoption manually.
        :param pulumi.Input[_builtins.bool] disabled: Whether the device is administratively disabled. When true, the device will not forward traffic or provide services.
        :param pulumi.Input[_builtins.bool] forget_on_destroy: Whether to forget (un-adopt) the device when this resource is destroyed. When true:
               * The device will be removed from the controller
               * The device will need to be readopted to be managed again
               * Device configuration will be reset
               Set to false to keep the device adopted when removing from Terraform management.
        :param pulumi.Input[_builtins.str] mac: The MAC address of the device in standard format (e.g., 'aa:bb:cc:dd:ee:ff'). This is used to identify and manage specific devices that have already been adopted by the controller.
        :param pulumi.Input[_builtins.str] name: A friendly name for the device that will be displayed in the UniFi controller UI. Examples:
               * 'Office-AP-1' for an access point
               * 'Core-Switch-01' for a switch
               * 'Main-Gateway' for a gateway
               Choose descriptive names that indicate location and purpose.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DevicePortOverrideArgs', 'DevicePortOverrideArgsDict']]]] port_overrides: A list of port-specific configuration overrides for UniFi switches. This allows you to customize individual port settings such as:
                 * Port names and labels for easy identification
                 * Port profiles for VLAN and security settings
                 * Operating modes for special functions
               
               Common use cases include:
                 * Setting up trunk ports for inter-switch connections
                 * Configuring PoE settings for powered devices
                 * Creating mirrored ports for network monitoring
                 * Setting up link aggregation between switches or servers
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the device is located. If not specified, the default site will be used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeviceState.__new__(_DeviceState)

        __props__.__dict__["allow_adoption"] = allow_adoption
        __props__.__dict__["disabled"] = disabled
        __props__.__dict__["forget_on_destroy"] = forget_on_destroy
        __props__.__dict__["mac"] = mac
        __props__.__dict__["name"] = name
        __props__.__dict__["port_overrides"] = port_overrides
        __props__.__dict__["site"] = site
        return Device(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowAdoption")
    def allow_adoption(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to automatically adopt the device when creating this resource. When true:
        * The controller will attempt to adopt the device
        * Device must be in a pending adoption state
        * Device must be accessible on the network
        Set to false if you want to manage adoption manually.
        """
        return pulumi.get(self, "allow_adoption")

    @_builtins.property
    @pulumi.getter
    def disabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the device is administratively disabled. When true, the device will not forward traffic or provide services.
        """
        return pulumi.get(self, "disabled")

    @_builtins.property
    @pulumi.getter(name="forgetOnDestroy")
    def forget_on_destroy(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to forget (un-adopt) the device when this resource is destroyed. When true:
        * The device will be removed from the controller
        * The device will need to be readopted to be managed again
        * Device configuration will be reset
        Set to false to keep the device adopted when removing from Terraform management.
        """
        return pulumi.get(self, "forget_on_destroy")

    @_builtins.property
    @pulumi.getter
    def mac(self) -> pulumi.Output[_builtins.str]:
        """
        The MAC address of the device in standard format (e.g., 'aa:bb:cc:dd:ee:ff'). This is used to identify and manage specific devices that have already been adopted by the controller.
        """
        return pulumi.get(self, "mac")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A friendly name for the device that will be displayed in the UniFi controller UI. Examples:
        * 'Office-AP-1' for an access point
        * 'Core-Switch-01' for a switch
        * 'Main-Gateway' for a gateway
        Choose descriptive names that indicate location and purpose.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="portOverrides")
    def port_overrides(self) -> pulumi.Output[Optional[Sequence['outputs.DevicePortOverride']]]:
        """
        A list of port-specific configuration overrides for UniFi switches. This allows you to customize individual port settings such as:
          * Port names and labels for easy identification
          * Port profiles for VLAN and security settings
          * Operating modes for special functions

        Common use cases include:
          * Setting up trunk ports for inter-switch connections
          * Configuring PoE settings for powered devices
          * Creating mirrored ports for network monitoring
          * Setting up link aggregation between switches or servers
        """
        return pulumi.get(self, "port_overrides")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where the device is located. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NtpArgs', 'Ntp']

@pulumi.input_type
class NtpArgs:
    def __init__(__self__, *,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server1: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server2: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server3: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server4: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Ntp resource.
        :param pulumi.Input[_builtins.str] mode: NTP server configuration mode. Valid values are:
        :param pulumi.Input[_builtins.str] ntp_server1: Primary NTP server hostname or IP address. Must be a valid hostname (e.g., `pool.ntp.org`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server2: Secondary NTP server hostname or IP address. Must be a valid hostname (e.g., `time.google.com`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server3: Tertiary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server4: Quaternary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if ntp_server1 is not None:
            pulumi.set(__self__, "ntp_server1", ntp_server1)
        if ntp_server2 is not None:
            pulumi.set(__self__, "ntp_server2", ntp_server2)
        if ntp_server3 is not None:
            pulumi.set(__self__, "ntp_server3", ntp_server3)
        if ntp_server4 is not None:
            pulumi.set(__self__, "ntp_server4", ntp_server4)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        NTP server configuration mode. Valid values are:
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mode", value)

    @_builtins.property
    @pulumi.getter(name="ntpServer1")
    def ntp_server1(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Primary NTP server hostname or IP address. Must be a valid hostname (e.g., `pool.ntp.org`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server1")

    @ntp_server1.setter
    def ntp_server1(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ntp_server1", value)

    @_builtins.property
    @pulumi.getter(name="ntpServer2")
    def ntp_server2(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secondary NTP server hostname or IP address. Must be a valid hostname (e.g., `time.google.com`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server2")

    @ntp_server2.setter
    def ntp_server2(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ntp_server2", value)

    @_builtins.property
    @pulumi.getter(name="ntpServer3")
    def ntp_server3(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Tertiary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server3")

    @ntp_server3.setter
    def ntp_server3(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ntp_server3", value)

    @_builtins.property
    @pulumi.getter(name="ntpServer4")
    def ntp_server4(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Quaternary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server4")

    @ntp_server4.setter
    def ntp_server4(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ntp_server4", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _NtpState:
    def __init__(__self__, *,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server1: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server2: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server3: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server4: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Ntp resources.
        :param pulumi.Input[_builtins.str] mode: NTP server configuration mode. Valid values are:
        :param pulumi.Input[_builtins.str] ntp_server1: Primary NTP server hostname or IP address. Must be a valid hostname (e.g., `pool.ntp.org`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server2: Secondary NTP server hostname or IP address. Must be a valid hostname (e.g., `time.google.com`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server3: Tertiary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server4: Quaternary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if ntp_server1 is not None:
            pulumi.set(__self__, "ntp_server1", ntp_server1)
        if ntp_server2 is not None:
            pulumi.set(__self__, "ntp_server2", ntp_server2)
        if ntp_server3 is not None:
            pulumi.set(__self__, "ntp_server3", ntp_server3)
        if ntp_server4 is not None:
            pulumi.set(__self__, "ntp_server4", ntp_server4)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        NTP server configuration mode. Valid values are:
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mode", value)

    @_builtins.property
    @pulumi.getter(name="ntpServer1")
    def ntp_server1(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Primary NTP server hostname or IP address. Must be a valid hostname (e.g., `pool.ntp.org`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server1")

    @ntp_server1.setter
    def ntp_server1(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ntp_server1", value)

    @_builtins.property
    @pulumi.getter(name="ntpServer2")
    def ntp_server2(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secondary NTP server hostname or IP address. Must be a valid hostname (e.g., `time.google.com`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server2")

    @ntp_server2.setter
    def ntp_server2(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ntp_server2", value)

    @_builtins.property
    @pulumi.getter(name="ntpServer3")
    def ntp_server3(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Tertiary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server3")

    @ntp_server3.setter
    def ntp_server3(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ntp_server3", value)

    @_builtins.property
    @pulumi.getter(name="ntpServer4")
    def ntp_server4(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Quaternary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server4")

    @ntp_server4.setter
    def ntp_server4(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ntp_server4", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.type_token("unifi:setting/ntp:Ntp")
class Ntp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server1: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server2: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server3: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server4: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `setting.Ntp` resource allows you to configure Network Time Protocol (NTP) server settings for your UniFi network.

        NTP servers provide time synchronization for your network devices. This resource supports both automatic and manual NTP configuration modes.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        example = unifi.setting.Ntp("example",
            mode="manual",
            ntp_server1="time.cloudflare.com",
            ntp_server2="pool.ntp.org",
            ntp_server3="time.google.com",
            ntp_server4="0.pool.ntp.org")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] mode: NTP server configuration mode. Valid values are:
        :param pulumi.Input[_builtins.str] ntp_server1: Primary NTP server hostname or IP address. Must be a valid hostname (e.g., `pool.ntp.org`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server2: Secondary NTP server hostname or IP address. Must be a valid hostname (e.g., `time.google.com`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server3: Tertiary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server4: Quaternary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[NtpArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `setting.Ntp` resource allows you to configure Network Time Protocol (NTP) server settings for your UniFi network.

        NTP servers provide time synchronization for your network devices. This resource supports both automatic and manual NTP configuration modes.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        example = unifi.setting.Ntp("example",
            mode="manual",
            ntp_server1="time.cloudflare.com",
            ntp_server2="pool.ntp.org",
            ntp_server3="time.google.com",
            ntp_server4="0.pool.ntp.org")
        ```

        :param str resource_name: The name of the resource.
        :param NtpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NtpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server1: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server2: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server3: Optional[pulumi.Input[_builtins.str]] = None,
                 ntp_server4: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NtpArgs.__new__(NtpArgs)

            __props__.__dict__["mode"] = mode
            __props__.__dict__["ntp_server1"] = ntp_server1
            __props__.__dict__["ntp_server2"] = ntp_server2
            __props__.__dict__["ntp_server3"] = ntp_server3
            __props__.__dict__["ntp_server4"] = ntp_server4
            __props__.__dict__["site"] = site
        super(Ntp, __self__).__init__(
            'unifi:setting/ntp:Ntp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            mode: Optional[pulumi.Input[_builtins.str]] = None,
            ntp_server1: Optional[pulumi.Input[_builtins.str]] = None,
            ntp_server2: Optional[pulumi.Input[_builtins.str]] = None,
            ntp_server3: Optional[pulumi.Input[_builtins.str]] = None,
            ntp_server4: Optional[pulumi.Input[_builtins.str]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None) -> 'Ntp':
        """
        Get an existing Ntp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] mode: NTP server configuration mode. Valid values are:
        :param pulumi.Input[_builtins.str] ntp_server1: Primary NTP server hostname or IP address. Must be a valid hostname (e.g., `pool.ntp.org`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server2: Secondary NTP server hostname or IP address. Must be a valid hostname (e.g., `time.google.com`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server3: Tertiary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] ntp_server4: Quaternary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NtpState.__new__(_NtpState)

        __props__.__dict__["mode"] = mode
        __props__.__dict__["ntp_server1"] = ntp_server1
        __props__.__dict__["ntp_server2"] = ntp_server2
        __props__.__dict__["ntp_server3"] = ntp_server3
        __props__.__dict__["ntp_server4"] = ntp_server4
        __props__.__dict__["site"] = site
        return Ntp(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> pulumi.Output[_builtins.str]:
        """
        NTP server configuration mode. Valid values are:
        """
        return pulumi.get(self, "mode")

    @_builtins.property
    @pulumi.getter(name="ntpServer1")
    def ntp_server1(self) -> pulumi.Output[_builtins.str]:
        """
        Primary NTP server hostname or IP address. Must be a valid hostname (e.g., `pool.ntp.org`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server1")

    @_builtins.property
    @pulumi.getter(name="ntpServer2")
    def ntp_server2(self) -> pulumi.Output[_builtins.str]:
        """
        Secondary NTP server hostname or IP address. Must be a valid hostname (e.g., `time.google.com`) or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server2")

    @_builtins.property
    @pulumi.getter(name="ntpServer3")
    def ntp_server3(self) -> pulumi.Output[_builtins.str]:
        """
        Tertiary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server3")

    @_builtins.property
    @pulumi.getter(name="ntpServer4")
    def ntp_server4(self) -> pulumi.Output[_builtins.str]:
        """
        Quaternary NTP server hostname or IP address. Must be a valid hostname or IPv4 address. Only applicable when `mode` is set to `manual`.
        """
        return pulumi.get(self, "ntp_server4")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DynamicDNSArgs', 'DynamicDNS']

@pulumi.input_type
class DynamicDNSArgs:
    def __init__(__self__, *,
                 host_name: pulumi.Input[_builtins.str],
                 service: pulumi.Input[_builtins.str],
                 interface: Optional[pulumi.Input[_builtins.str]] = None,
                 login: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 server: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DynamicDNS resource.
        :param pulumi.Input[_builtins.str] host_name: The fully qualified domain name to update with your current public IP address (e.g., 'myhouse.dyndns.org' or 'myoffice.no-ip.com').
        :param pulumi.Input[_builtins.str] service: The Dynamic DNS service provider. Common values include:
                 * `dyndns` - DynDNS service
                 * `noip` - No-IP service
                 * `duckdns` - Duck DNS service
               Check your UniFi controller for the complete list of supported providers.
        :param pulumi.Input[_builtins.str] interface: The WAN interface to use for the dynamic DNS updates. Valid values are:
                 * `wan` - Primary WAN interface (default)
                 * `wan2` - Secondary WAN interface
        :param pulumi.Input[_builtins.str] login: The username or login for your DDNS provider account.
        :param pulumi.Input[_builtins.str] password: The password or token for your DDNS provider account. This value will be stored securely and not displayed in logs.
        :param pulumi.Input[_builtins.str] server: The update server hostname for your DDNS provider. Usually not required as the UniFi controller knows the correct servers for common providers.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the dynamic DNS configuration should be created. If not specified, the default site will be used.
        """
        pulumi.set(__self__, "host_name", host_name)
        pulumi.set(__self__, "service", service)
        if interface is not None:
            pulumi.set(__self__, "interface", interface)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if server is not None:
            pulumi.set(__self__, "server", server)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Input[_builtins.str]:
        """
        The fully qualified domain name to update with your current public IP address (e.g., 'myhouse.dyndns.org' or 'myoffice.no-ip.com').
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "host_name", value)

    @_builtins.property
    @pulumi.getter
    def service(self) -> pulumi.Input[_builtins.str]:
        """
        The Dynamic DNS service provider. Common values include:
          * `dyndns` - DynDNS service
          * `noip` - No-IP service
          * `duckdns` - Duck DNS service
        Check your UniFi controller for the complete list of supported providers.
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service", value)

    @_builtins.property
    @pulumi.getter
    def interface(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The WAN interface to use for the dynamic DNS updates. Valid values are:
          * `wan` - Primary WAN interface (default)
          * `wan2` - Secondary WAN interface
        """
        return pulumi.get(self, "interface")

    @interface.setter
    def interface(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "interface", value)

    @_builtins.property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username or login for your DDNS provider account.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "login", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password or token for your DDNS provider account. This value will be stored securely and not displayed in logs.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def server(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The update server hostname for your DDNS provider. Usually not required as the UniFi controller knows the correct servers for common providers.
        """
        return pulumi.get(self, "server")

    @server.setter
    def server(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "server", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the dynamic DNS configuration should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _DynamicDNSState:
    def __init__(__self__, *,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 interface: Optional[pulumi.Input[_builtins.str]] = None,
                 login: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 server: Optional[pulumi.Input[_builtins.str]] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DynamicDNS resources.
        :param pulumi.Input[_builtins.str] host_name: The fully qualified domain name to update with your current public IP address (e.g., 'myhouse.dyndns.org' or 'myoffice.no-ip.com').
        :param pulumi.Input[_builtins.str] interface: The WAN interface to use for the dynamic DNS updates. Valid values are:
                 * `wan` - Primary WAN interface (default)
                 * `wan2` - Secondary WAN interface
        :param pulumi.Input[_builtins.str] login: The username or login for your DDNS provider account.
        :param pulumi.Input[_builtins.str] password: The password or token for your DDNS provider account. This value will be stored securely and not displayed in logs.
        :param pulumi.Input[_builtins.str] server: The update server hostname for your DDNS provider. Usually not required as the UniFi controller knows the correct servers for common providers.
        :param pulumi.Input[_builtins.str] service: The Dynamic DNS service provider. Common values include:
                 * `dyndns` - DynDNS service
                 * `noip` - No-IP service
                 * `duckdns` - Duck DNS service
               Check your UniFi controller for the complete list of supported providers.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the dynamic DNS configuration should be created. If not specified, the default site will be used.
        """
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if interface is not None:
            pulumi.set(__self__, "interface", interface)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if server is not None:
            pulumi.set(__self__, "server", server)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fully qualified domain name to update with your current public IP address (e.g., 'myhouse.dyndns.org' or 'myoffice.no-ip.com').
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host_name", value)

    @_builtins.property
    @pulumi.getter
    def interface(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The WAN interface to use for the dynamic DNS updates. Valid values are:
          * `wan` - Primary WAN interface (default)
          * `wan2` - Secondary WAN interface
        """
        return pulumi.get(self, "interface")

    @interface.setter
    def interface(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "interface", value)

    @_builtins.property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username or login for your DDNS provider account.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "login", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password or token for your DDNS provider account. This value will be stored securely and not displayed in logs.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def server(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The update server hostname for your DDNS provider. Usually not required as the UniFi controller knows the correct servers for common providers.
        """
        return pulumi.get(self, "server")

    @server.setter
    def server(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "server", value)

    @_builtins.property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Dynamic DNS service provider. Common values include:
          * `dyndns` - DynDNS service
          * `noip` - No-IP service
          * `duckdns` - Duck DNS service
        Check your UniFi controller for the complete list of supported providers.
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the dynamic DNS configuration should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.type_token("unifi:index/dynamicDNS:DynamicDNS")
class DynamicDNS(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 interface: Optional[pulumi.Input[_builtins.str]] = None,
                 login: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 server: Optional[pulumi.Input[_builtins.str]] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `DynamicDNS` resource manages Dynamic DNS (DDNS).

        Dynamic DNS allows you to access your network using a domain name even when your public IP address changes. This is useful for:
          * Remote access to your network
          * Hosting services from your home/office network
          * VPN connections to your network

        The resource supports various DDNS providers including:
          * DynDNS
          * No-IP
          * Duck DNS
          * And many others

        Each DDNS configuration can be associated with either the primary (WAN) or secondary (WAN2) interface.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.DynamicDNS("test",
            service="dyndns",
            host_name="my-network.example.com",
            server="domains.google.com",
            login=dns_login,
            password=dns_password)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] host_name: The fully qualified domain name to update with your current public IP address (e.g., 'myhouse.dyndns.org' or 'myoffice.no-ip.com').
        :param pulumi.Input[_builtins.str] interface: The WAN interface to use for the dynamic DNS updates. Valid values are:
                 * `wan` - Primary WAN interface (default)
                 * `wan2` - Secondary WAN interface
        :param pulumi.Input[_builtins.str] login: The username or login for your DDNS provider account.
        :param pulumi.Input[_builtins.str] password: The password or token for your DDNS provider account. This value will be stored securely and not displayed in logs.
        :param pulumi.Input[_builtins.str] server: The update server hostname for your DDNS provider. Usually not required as the UniFi controller knows the correct servers for common providers.
        :param pulumi.Input[_builtins.str] service: The Dynamic DNS service provider. Common values include:
                 * `dyndns` - DynDNS service
                 * `noip` - No-IP service
                 * `duckdns` - Duck DNS service
               Check your UniFi controller for the complete list of supported providers.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the dynamic DNS configuration should be created. If not specified, the default site will be used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DynamicDNSArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `DynamicDNS` resource manages Dynamic DNS (DDNS).

        Dynamic DNS allows you to access your network using a domain name even when your public IP address changes. This is useful for:
          * Remote access to your network
          * Hosting services from your home/office network
          * VPN connections to your network

        The resource supports various DDNS providers including:
          * DynDNS
          * No-IP
          * Duck DNS
          * And many others

        Each DDNS configuration can be associated with either the primary (WAN) or secondary (WAN2) interface.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.DynamicDNS("test",
            service="dyndns",
            host_name="my-network.example.com",
            server="domains.google.com",
            login=dns_login,
            password=dns_password)
        ```

        :param str resource_name: The name of the resource.
        :param DynamicDNSArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DynamicDNSArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 interface: Optional[pulumi.Input[_builtins.str]] = None,
                 login: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 server: Optional[pulumi.Input[_builtins.str]] = None,
                 service: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DynamicDNSArgs.__new__(DynamicDNSArgs)

            if host_name is None and not opts.urn:
                raise TypeError("Missing required property 'host_name'")
            __props__.__dict__["host_name"] = host_name
            __props__.__dict__["interface"] = interface
            __props__.__dict__["login"] = login
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["server"] = server
            if service is None and not opts.urn:
                raise TypeError("Missing required property 'service'")
            __props__.__dict__["service"] = service
            __props__.__dict__["site"] = site
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(DynamicDNS, __self__).__init__(
            'unifi:index/dynamicDNS:DynamicDNS',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            host_name: Optional[pulumi.Input[_builtins.str]] = None,
            interface: Optional[pulumi.Input[_builtins.str]] = None,
            login: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            server: Optional[pulumi.Input[_builtins.str]] = None,
            service: Optional[pulumi.Input[_builtins.str]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None) -> 'DynamicDNS':
        """
        Get an existing DynamicDNS resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] host_name: The fully qualified domain name to update with your current public IP address (e.g., 'myhouse.dyndns.org' or 'myoffice.no-ip.com').
        :param pulumi.Input[_builtins.str] interface: The WAN interface to use for the dynamic DNS updates. Valid values are:
                 * `wan` - Primary WAN interface (default)
                 * `wan2` - Secondary WAN interface
        :param pulumi.Input[_builtins.str] login: The username or login for your DDNS provider account.
        :param pulumi.Input[_builtins.str] password: The password or token for your DDNS provider account. This value will be stored securely and not displayed in logs.
        :param pulumi.Input[_builtins.str] server: The update server hostname for your DDNS provider. Usually not required as the UniFi controller knows the correct servers for common providers.
        :param pulumi.Input[_builtins.str] service: The Dynamic DNS service provider. Common values include:
                 * `dyndns` - DynDNS service
                 * `noip` - No-IP service
                 * `duckdns` - Duck DNS service
               Check your UniFi controller for the complete list of supported providers.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the dynamic DNS configuration should be created. If not specified, the default site will be used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DynamicDNSState.__new__(_DynamicDNSState)

        __props__.__dict__["host_name"] = host_name
        __props__.__dict__["interface"] = interface
        __props__.__dict__["login"] = login
        __props__.__dict__["password"] = password
        __props__.__dict__["server"] = server
        __props__.__dict__["service"] = service
        __props__.__dict__["site"] = site
        return DynamicDNS(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Output[_builtins.str]:
        """
        The fully qualified domain name to update with your current public IP address (e.g., 'myhouse.dyndns.org' or 'myoffice.no-ip.com').
        """
        return pulumi.get(self, "host_name")

    @_builtins.property
    @pulumi.getter
    def interface(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The WAN interface to use for the dynamic DNS updates. Valid values are:
          * `wan` - Primary WAN interface (default)
          * `wan2` - Secondary WAN interface
        """
        return pulumi.get(self, "interface")

    @_builtins.property
    @pulumi.getter
    def login(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The username or login for your DDNS provider account.
        """
        return pulumi.get(self, "login")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The password or token for your DDNS provider account. This value will be stored securely and not displayed in logs.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def server(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The update server hostname for your DDNS provider. Usually not required as the UniFi controller knows the correct servers for common providers.
        """
        return pulumi.get(self, "server")

    @_builtins.property
    @pulumi.getter
    def service(self) -> pulumi.Output[_builtins.str]:
        """
        The Dynamic DNS service provider. Common values include:
          * `dyndns` - DynDNS service
          * `noip` - No-IP service
          * `duckdns` - Duck DNS service
        Check your UniFi controller for the complete list of supported providers.
        """
        return pulumi.get(self, "service")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where the dynamic DNS configuration should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'DevicePortOverride',
    'RadiusProfileAcctServer',
    'RadiusProfileAuthServer',
    'WlanSchedule',
]

@pulumi.output_type
class DevicePortOverride(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "aggregateNumPorts":
            suggest = "aggregate_num_ports"
        elif key == "opMode":
            suggest = "op_mode"
        elif key == "poeMode":
            suggest = "poe_mode"
        elif key == "portProfileId":
            suggest = "port_profile_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DevicePortOverride. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DevicePortOverride.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DevicePortOverride.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 number: _builtins.int,
                 aggregate_num_ports: Optional[_builtins.int] = None,
                 name: Optional[_builtins.str] = None,
                 op_mode: Optional[_builtins.str] = None,
                 poe_mode: Optional[_builtins.str] = None,
                 port_profile_id: Optional[_builtins.str] = None):
        """
        :param _builtins.int number: The physical port number on the switch to configure.
        :param _builtins.int aggregate_num_ports: The number of ports to include in a link aggregation group (LAG). Valid range: 2-8 ports. Used when:
               * Creating switch-to-switch uplinks for increased bandwidth
               * Setting up high-availability connections
               * Connecting to servers requiring more bandwidth
               Note: All ports in the LAG must be sequential and have matching configurations.
        :param _builtins.str name: A friendly name for the port that will be displayed in the UniFi controller UI. Examples:
                 * 'Uplink to Core Switch'
                 * 'Conference Room AP'
                 * 'Server LACP Group 1'
                 * 'VoIP Phone Port'
        :param _builtins.str op_mode: The operating mode of the port. Valid values are:
                 * `switch` - Normal switching mode (default)
                   - Standard port operation for connecting devices
                   - Supports VLANs and all standard switching features
                 * `mirror` - Port mirroring for traffic analysis
                   - Copies traffic from other ports for monitoring
                   - Useful for network troubleshooting and security
                 * `aggregate` - Link aggregation/bonding mode
                   - Combines multiple ports for increased bandwidth
                   - Used for switch uplinks or high-bandwidth servers
        :param _builtins.str poe_mode: The Power over Ethernet (PoE) mode for the port. Valid values are:
               * `auto` - Automatically detect and power PoE devices (recommended)
                 - Provides power based on device negotiation
                 - Safest option for most PoE devices
               * `pasv24` - Passive 24V PoE
                 - For older UniFi devices requiring passive 24V
                 - Use with caution to avoid damage
               * `passthrough` - PoE passthrough mode
                 - For daisy-chaining PoE devices
                 - Available on select UniFi switches
               * `off` - Disable PoE on the port
                 - For non-PoE devices
                 - To prevent unwanted power delivery
        :param _builtins.str port_profile_id: The ID of a pre-configured port profile to apply to this port. Port profiles define settings like VLANs, PoE, and other port-specific configurations.
        """
        pulumi.set(__self__, "number", number)
        if aggregate_num_ports is not None:
            pulumi.set(__self__, "aggregate_num_ports", aggregate_num_ports)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if op_mode is not None:
            pulumi.set(__self__, "op_mode", op_mode)
        if poe_mode is not None:
            pulumi.set(__self__, "poe_mode", poe_mode)
        if port_profile_id is not None:
            pulumi.set(__self__, "port_profile_id", port_profile_id)

    @_builtins.property
    @pulumi.getter
    def number(self) -> _builtins.int:
        """
        The physical port number on the switch to configure.
        """
        return pulumi.get(self, "number")

    @_builtins.property
    @pulumi.getter(name="aggregateNumPorts")
    def aggregate_num_ports(self) -> Optional[_builtins.int]:
        """
        The number of ports to include in a link aggregation group (LAG). Valid range: 2-8 ports. Used when:
        * Creating switch-to-switch uplinks for increased bandwidth
        * Setting up high-availability connections
        * Connecting to servers requiring more bandwidth
        Note: All ports in the LAG must be sequential and have matching configurations.
        """
        return pulumi.get(self, "aggregate_num_ports")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        A friendly name for the port that will be displayed in the UniFi controller UI. Examples:
          * 'Uplink to Core Switch'
          * 'Conference Room AP'
          * 'Server LACP Group 1'
          * 'VoIP Phone Port'
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="opMode")
    def op_mode(self) -> Optional[_builtins.str]:
        """
        The operating mode of the port. Valid values are:
          * `switch` - Normal switching mode (default)
            - Standard port operation for connecting devices
            - Supports VLANs and all standard switching features
          * `mirror` - Port mirroring for traffic analysis
            - Copies traffic from other ports for monitoring
            - Useful for network troubleshooting and security
          * `aggregate` - Link aggregation/bonding mode
            - Combines multiple ports for increased bandwidth
            - Used for switch uplinks or high-bandwidth servers
        """
        return pulumi.get(self, "op_mode")

    @_builtins.property
    @pulumi.getter(name="poeMode")
    def poe_mode(self) -> Optional[_builtins.str]:
        """
        The Power over Ethernet (PoE) mode for the port. Valid values are:
        * `auto` - Automatically detect and power PoE devices (recommended)
          - Provides power based on device negotiation
          - Safest option for most PoE devices
        * `pasv24` - Passive 24V PoE
          - For older UniFi devices requiring passive 24V
          - Use with caution to avoid damage
        * `passthrough` - PoE passthrough mode
          - For daisy-chaining PoE devices
          - Available on select UniFi switches
        * `off` - Disable PoE on the port
          - For non-PoE devices
          - To prevent unwanted power delivery
        """
        return pulumi.get(self, "poe_mode")

    @_builtins.property
    @pulumi.getter(name="portProfileId")
    def port_profile_id(self) -> Optional[_builtins.str]:
        """
        The ID of a pre-configured port profile to apply to this port. Port profiles define settings like VLANs, PoE, and other port-specific configurations.
        """
        return pulumi.get(self, "port_profile_id")


@pulumi.output_type
class RadiusProfileAcctServer(dict):
    def __init__(__self__, *,
                 ip: _builtins.str,
                 xsecret: _builtins.str,
                 port: Optional[_builtins.int] = None):
        """
        :param _builtins.str ip: The IPv4 address of the RADIUS accounting server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
        :param _builtins.str xsecret: The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
        :param _builtins.int port: The UDP port number where the RADIUS accounting service is listening. The standard port is 1813, but this can be changed if needed to match your server configuration.
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "xsecret", xsecret)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        """
        The IPv4 address of the RADIUS accounting server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def xsecret(self) -> _builtins.str:
        """
        The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
        """
        return pulumi.get(self, "xsecret")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        The UDP port number where the RADIUS accounting service is listening. The standard port is 1813, but this can be changed if needed to match your server configuration.
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class RadiusProfileAuthServer(dict):
    def __init__(__self__, *,
                 ip: _builtins.str,
                 xsecret: _builtins.str,
                 port: Optional[_builtins.int] = None):
        """
        :param _builtins.str ip: The IPv4 address of the RADIUS authentication server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
        :param _builtins.str xsecret: The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
        :param _builtins.int port: The UDP port number where the RADIUS authentication service is listening. The standard port is 1812, but this can be changed if needed to match your server configuration.
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "xsecret", xsecret)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        """
        The IPv4 address of the RADIUS authentication server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def xsecret(self) -> _builtins.str:
        """
        The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
        """
        return pulumi.get(self, "xsecret")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        The UDP port number where the RADIUS authentication service is listening. The standard port is 1812, but this can be changed if needed to match your server configuration.
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class WlanSchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dayOfWeek":
            suggest = "day_of_week"
        elif key == "startHour":
            suggest = "start_hour"
        elif key == "startMinute":
            suggest = "start_minute"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WlanSchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WlanSchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WlanSchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 day_of_week: _builtins.str,
                 duration: _builtins.int,
                 start_hour: _builtins.int,
                 name: Optional[_builtins.str] = None,
                 start_minute: Optional[_builtins.int] = None):
        """
        :param _builtins.str day_of_week: Day of week. Valid values: `sun`, `mon`, `tue`, `wed`, `thu`, `fri`, `sat`.
        :param _builtins.int duration: Duration in minutes that the network should remain active.
        :param _builtins.int start_hour: Start hour in 24-hour format (0-23).
        :param _builtins.str name: Friendly name for this schedule block (e.g., 'Business Hours', 'Weekend Access').
        :param _builtins.int start_minute: Start minute (0-59).
        """
        pulumi.set(__self__, "day_of_week", day_of_week)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "start_hour", start_hour)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if start_minute is not None:
            pulumi.set(__self__, "start_minute", start_minute)

    @_builtins.property
    @pulumi.getter(name="dayOfWeek")
    def day_of_week(self) -> _builtins.str:
        """
        Day of week. Valid values: `sun`, `mon`, `tue`, `wed`, `thu`, `fri`, `sat`.
        """
        return pulumi.get(self, "day_of_week")

    @_builtins.property
    @pulumi.getter
    def duration(self) -> _builtins.int:
        """
        Duration in minutes that the network should remain active.
        """
        return pulumi.get(self, "duration")

    @_builtins.property
    @pulumi.getter(name="startHour")
    def start_hour(self) -> _builtins.int:
        """
        Start hour in 24-hour format (0-23).
        """
        return pulumi.get(self, "start_hour")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Friendly name for this schedule block (e.g., 'Business Hours', 'Weekend Access').
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="startMinute")
    def start_minute(self) -> Optional[_builtins.int]:
        """
        Start minute (0-59).
        """
        return pulumi.get(self, "start_minute")


